@@ -1,7 +1,6 @@
 from itertools import product
 from overrides import overrides
 
-from pytorch_lightning.utilities.seed import seed_everything as pl_set_seed
 import pytorch_lightning as pl
 from sklearn.base import BaseEstimator
 from sklearn.model_selection import StratifiedKFold, train_test_split
@@ -65,8 +64,6 @@ class CrossValidation(BaseExperiment):
         """
         self.rng = np.random.default_rng(random_number)
         self.seed_num = int(10**6 * self.rng.random(1))
-        pl_set_seed(self.seed_num)
-        np.random.seed(self.seed_num)
         
         super().__init__(
             project_name=project_name,
@@ -77,7 +74,7 @@ class CrossValidation(BaseExperiment):
             y_test=y_test,
             test_size=test_size,
             stack_models=stack_models,
-            random_state=self.seed_num,
+            random_number=self.seed_num,
             path=path
         )
         self.model_type = model_type
@@ -97,7 +94,7 @@ class CrossValidation(BaseExperiment):
         self.n_random_search = 5 if not n_random_search else n_random_search
 
     def get_cv_indices(self):
-        skf = StratifiedKFold(n_splits=self.cv, random_state=self.seed_num, shuffle=True)
+        skf = StratifiedKFold(n_splits=self.cv, random_state=self.random_state, shuffle=True)
         cv_indices = []
         for train_idx, val_idx in skf.split(self.X, self.y):
             cv_indices.append((train_idx, val_idx))
@@ -184,14 +181,14 @@ class CrossValidation(BaseExperiment):
             elif X_val and y_val and X_test and y_test:
                 data_module = (X, X_val, y, y_val, X_test, y_test)
             elif X_test and y_test:
-                X_train, X_val, y_train, y_val = train_test_split(X, y, test_size=test_size, random_state=self.seed_num, stratify=y)
+                X_train, X_val, y_train, y_val = train_test_split(X, y, test_size=test_size, random_state=self.random_state, stratify=y)
                 data_module = (X_train, X_val, y_train, y_val, X_test, y_test)
             elif X_val and y_val:
-                X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=test_size, random_state=self.seed_num, stratify=y)
-                X_train, X_val, y_train, y_val = train_test_split(X, y, test_size=test_size, random_state=self.seed_num, stratify=y)
+                X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=test_size, random_state=self.random_state, stratify=y)
+                X_train, X_val, y_train, y_val = train_test_split(X, y, test_size=test_size, random_state=self.random_state, stratify=y)
                 data_module = (X_train, X_val, y_train, y_val, X_test, y_test)
             elif X_val and y_val:
-                X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=test_size, random_state=self.seed_num, stratify=y)
+                X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=test_size, random_state=self.random_state, stratify=y)
                 data_module = (X_train, X_val, y_train, y_val, X_test, y_test)
 
         elif pl.LightningModule in inspect.getmro(self.model_type):
@@ -204,7 +201,7 @@ class CrossValidation(BaseExperiment):
                 X_test=X_test,
                 y_test=y_test,
                 test_size=test_size,
-                random_state=self.seed_num
+                random_state=self.random_state
             )
 
         return data_module
